<?
/*
    +----------------------------------------------------------------------+
    | Ossigeno is a modularized CMS                                        |
    | Copyright (C) 2004-2007 Neovision                                    |
    | [http://www.neovision.it]                                            |
    | Giorgio Sironi, Roberto Reposo                                       |
    +----------------------------------------------------------------------+
    |  This program is free software; you can redistribute it and/or       |
    | modify it under the terms of the GNU General Public License as       |
    | published by the Free Software Foundation; either version 2 of the   |
    | License, or (at your option) any later version.                      |
    |  This program is distributed in the hope that it will be useful,     |
    | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
    | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
    | GNU General Public License for more details.                         |
    |  You should have received a copy of the GNU General Public License   |
    | along with this program; if not, write to the Free Software          |
    | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
    | USA                                                                  |
    +----------------------------------------------------------------------+
    Library: html_forms
    File
    /common/classes/html_forms.php
    This file defines classes for xhmtl forms management
*/

require_once("html_tags.php");

class OTK_Form extends OTK_Tag
{
    function OTK_Form($action, $method = "post", $required_fields = array())
    {
        parent::OTK_Tag("form");
        $this->SetAttr("action", $action);
        $this->SetAttr("method", $method);
        if ($required_fields) {
            foreach ($required_fields as $key => $value) {
                $required_fields[$key] = "'{$value}'";
            }
            $onsubmit = "return otk_validate_form(new Array(" .
            implode(", ", $required_fields) .
            "));";
            $this->SetAttr("onsubmit", $onsubmit);
        }
    }
    function AddInputHidden($id, $value) {
        $tag = new OTK_InputHidden($id, $value);
        $p = new OTK_P();
        $p->SetAttr("class", "hidden");
        $p->AddChild($tag);
        $this->AddChild($p);
        return $tag;
    }
    function AddSecurityNumbers($id, $value) {
        $security = otk_security_numbers_generate();
        $this->AddInputHidden("id", $security["id"]);
          $this->AddInputHidden("number", $security["number"]);
    }
    function AddInputSubmit($value = FALSE)
    {
        if ($value === FALSE) {
            $tag = new OTK_InputSubmit();
        } else {
            $tag = new OTK_InputSubmit($value);
        }
        $this->AddChild($tag);
        return $tag;
    }
}

class OTK_Fieldset extends OTK_Tag
{
    function OTK_Fieldset($legend)
    {
        parent::OTK_Tag("fieldset");
        $tag = new OTK_Legend($legend);
        $this->AddChild($tag);
    }
    function AddLabel($label, $for)
    {
        $tag = new OTK_Label($label, $for);
        $this->AddChild($tag);
        return $tag;
    }
    function AddInput($id, $type, $value = "")
    {
        $tag = new OTK_Input($id, $type, $value);
        $this->AddChild($tag);
        return $tag;
    }
    function AddTextarea($id, $value = "")
    {
        $tag = new OTK_Textarea($id, $value);
        $this->AddChild($tag);
        return $tag;
    }
}

class OTK_Legend extends OTK_Tag
{
    function OTK_Legend($legend)
    {
        parent::OTK_Tag("legend");
        $this->text = $legend;
    }
}

class OTK_Label extends OTK_Tag
{
    function OTK_Label($label, $for) {
        parent::OTK_Tag("label");
        $this->text = $label;
        $this->SetAttr("for", $for);
    }
}

class OTK_Input extends OTK_Tag
{
    function OTK_Input($id, $type, $value = "")
    {
        parent::OTK_Tag("input");
        $this->SetAttr("type", $type);
        if ($id !== "") {
            $this->SetAttr("id", $id);
            $this->SetAttr("name", $id);
        }
        if ($value !== "") {
            $this->SetAttr("value", $value);
        }
    }
}

class OTK_InputButton extends OTK_Input
{
    function OTK_InputButton($id = "", $value = "")
    {
        parent::OTK_Input($id, "button", $value);
    }
}

class OTK_InputHidden extends OTK_Input
{
    function OTK_InputHidden($id, $value)
    {
        parent::OTK_Input($id, "hidden", $value);
    }
}

class OTK_InputPassword extends OTK_Input
{
    function OTK_InputPassword($id, $value = "")
    {
        parent::OTK_Input($id, "password", $value);
    }
}

class OTK_InputSubmit extends OTK_Input
{
    function OTK_InputSubmit($value = FALSE)
    {
        if ($value === FALSE) {
            $value = $_GLOBALS[$lang["submit"]];
        }
        parent::OTK_Input("submit", "submit", $value);
    }
}

class OTK_InputText extends OTK_Input
{
    function OTK_InputText($id, $value = "")
    {
        parent::OTK_Input($id, "text", $value);
    }
}

class OTK_Textarea extends OTK_Tag
{
    function OTK_Textarea($id, $value = "")
    {
        parent::OTK_Tag("textarea");
        $this->SetAttr("id", $id);
        $this->SetAttr("name", $id);
        $this->text = $value;
    }
}

class OTK_Smile extends OTK_Span
{
    function OTK_Smile($filename, $area = "text")
    {
        global $directory_smiles, $xax_version, $base, $ossigeno, $graphic_base;
        if ($xax_version) {
            $path = "{$base}{$ossigeno}{$graphic_base}";
        } else {
            $path = $graphic_base;
        }
        parent::OTK_Span("");
        $pieces = explode(".", $filename);
        $name = $pieces[0];
        $href = "javascript:otk_html_smile('{$name}', '{$area}');";
        $a = new OTK_A($href, "");
        $a->SetTitle(":{$name}:");
        $this->AddChild($a);
        $src = "{$path}smiles/{$filename}";
        $img = new OTK_Img($src);
        $a->AddChild($img);
    }
}

class OTK_HtmlButton extends OTK_Div
{
    function OTK_Button($name, $long = FALSE)
    {
        global $lang;
        parent::OTK_Div("");
        if ($long) {
            $this->SetAttr("class", "otk_tag_long");
        } else {
            $this->SetAttr("class", "otk_tag_short");
        }
        $a = new OTK_A("javascript:otk_html_{$name}('{$area}')", strtoupper($name));
        $a->SetTitle($lang["helps"]["html_buttons"][$name]);
    }
}
?>
